==> TbitOS_0_1.zip: mplay/mplay.c <==
/* fBAvC[ */

#include "../api/api.h"
#include <stdio.h>	/* strlen */

int strtol(char *s, char **endp, int base);	/* stdlib.h̊֐ */

void wait(int timer, int time);
void end(char *s);

void HariMain(void)
{
	/* ԍƎgimhzj̑Ή\
	 * FO4A440HzA4400000
	 * @@O16A1802240HzA1802240000
	 * IN^[u16XgiC`Bj
	 */
	static int ttable[12] = {
		1071618315, 1135340056, 1202850889, 1274376125, 1350154473, 1430438836,
		1515497155, 1605613306, 1701088041, 1802240000, 1909406767, 2022946002
	};
	static int ntable[7] = {9, 11, 0/* C */, 2, 4, 5, 7};
	char wbuf[208 * 64], tbuf[512 * 1024];			/* EBhEAeLXgobt@ */
	int win, timer, t = 120, l = 192 / 4, o = 4, q = 7;	/* nhƍĐp[h */
	int nold = 0, i, j;
	char s[32], *p, *r;

	/* t@C̎擾 */
	p = api_getcmd(s, 30, 0);

	/* t@C̓ǂݍ */
	i = api_fopen(p, 'r');
	if(i == 0) {
		end("̃t@C݂͑܂B");
	}
	j = api_fsize(i, 0);
	if(j > 256 * 1024 - 1) {
		j = 256 * 1024 - 1;
	}
	api_fread(i, tbuf, j);
	api_fclose(i);
	tbuf[j] = 0;
	r = tbuf;
	i = 0;	/* ʏ탂[h */

	/* EBhȄ */
	win = api_wopen(wbuf, 208, 64, -1, "fBAvC[");
	api_wnputs(win, COLOR_000000, 8, 32, p, 12);
	api_wbox(win, COLOR_FFFFFF, 120, 32, 200, 48);
	api_wrefresh(win, 120, 32, 201, 49);

	/* Rg󔒂̍폜 */
	for(p = tbuf; *p != 0; p++) {
		if(*p > ' ' && i == 0) {	/* Xy[XsR[hł͂Ȃ */
			if(*p == '#') {	/* sRg */
				i = 1;	/* sRg[h */
			} else {	/* ʂ̕ */
				*r = *p;
				if('a' <= *p && *p <= 'z') {	/* 啶ɕϊ */
					*r += 'A'-'a';
				}
				r++;
			}
		} else if(i == 1 && *p == 0x0a) {	/* s */
			i = 0;	/* ʃ[h */
		}
	}
	*r = (char) 0;

	/* ^C}̏ */
	timer = api_talloc();
	api_tinit(timer, 128);

	/* C */
	p = tbuf;
	for(;;){
		if(('A' <= *p && *p <= 'G') || *p == 'R') {	/* x */
			/* gvZ */
			if(*p == 'R') {
				i = 0;
			} else {
				i = o * 12 + ntable[*p - 'A'] + 12;
			}
			p++;
			if(*p == '+' || *p == '-') {
				if(*p == '-') {	/*  */
					i--;
				} else if(*p == '+') {	/* グ */
					i++;
				}
				p++;
			}
			if(i != nold) {
				if(28 <= nold && nold <= 107) {
					api_wbox(win, COLOR_FFFFFF, (nold - 28) + 120, 32, (nold - 28) + 120, 48);
					api_wrefresh(win, (nold - 28) + 120, 32, (nold - 28) + 121, 49);
				}
				if(28 <= i && i <= 107) {
					api_wbox(win, COLOR_000000, (i - 28) + 120, 32, (i - 28) + 120, 48);
					api_wrefresh(win, (i - 28) + 120, 32, (i - 28) + 121, 49);
				}
				if(i != 0) {
					api_beep(ttable[i % 12] >> (17 - i / 12));
				} else {
					api_beep(0);
				}
				nold = i;
			}
			/* vZ */
			if('0' <= *p && *p <= '9') {	/*  */
				i = 192 / strtol(p, &p, 10);
			} else {
				i = l;
			}
			for(; *p == '.'; p++) {	/* t_1/2𑫂Ă */
				i += i / 2;
			}
			i *= (60 * 100 / 48);
			i /= t;
			if(q < 8 && *p != '&') {	/* ^CƃX[ */
				j = i * q / 8;
				wait(timer, j);
				if(28 <= nold && nold <= 107) {
					api_wbox(win, COLOR_FFFFFF, (nold - 28) + 120, 32, (nold - 28) + 120, 48);
					api_wrefresh(win, (nold - 28) + 120, 32, (nold - 28) + 121, 49);
				}
				nold = 0;
				api_beep(0);
			} else {
				j = 0;
				if(*p == '&') {
					p++;
				}
			}
			wait(timer, i - j);
		} else if(*p == '<') {	/* IN^[u-- */
			p++;
			o--;
		} else if(*p == '>') {	/* IN^[u++ */
			p++;
			o++;
		} else if(*p == 'O') {	/* IN^[uw */
			o = strtol(p + 1, &p, 10);
		} else if(*p == 'Q') {	/* Qp[^w */
			q = strtol(p + 1, &p, 10);
		} else if(*p == 'L') {	/* ftHgw */
			l = strtol(p + 1, &p, 10);
			if(l == 0) {
				goto serror;
			}
			l = 192 / l;
			for(; *p == '.'; p++) {	/* t_1/2𑫂Ă */
				l += l / 2;
			}
		} else if(*p == 'T') {	/* e|w */
			t = strtol(p + 1, &p, 10);
		} else if(*p == 0) {
			p = tbuf;
		} else {
		serror:
			end("LqԈĂ܂B");
		}
	}
	api_exit();
}

void wait(int timer, int time)
{
	int i;

	api_tset(timer, time);
	for(;;) {
		i = api_getd(1);
		if(i == 128) {
			break;
		}
	}
	return;
}

void end(char *s)
{
	if(s != 0) {
		api_puts(s);
	}
	api_beep(0);
	api_exit();
}

==> TbitOS_0_2.zip: mplay/mplay.c <==
/* fBAvC[ */

#include "../api/api.h"
#include <stdio.h>	/* strlen */

int strtol(char *s, char **endp, int base);	/* stdlib.h̊֐ */

void drawbar(int win, int l, char mode);
void wait(int timer, int time);
void end(char *s);

void HariMain(void)
{
	/* ԍƎgimhzj̑Ή\
	 * FO4A440HzA4400000
	 * @@O16A1802240HzA1802240000
	 * IN^[u16XgiC`Bj
	 */
	static int ttable[12] = {
		1071618315, 1135340056, 1202850889, 1274376125, 1350154473, 1430438836,
		1515497155, 1605613306, 1701088041, 1802240000, 1909406767, 2022946002
	};
	static int ntable[7] = {9, 11, 0/* C */, 2, 4, 5, 7};
	char wbuf[235 * 37], tbuf[512 * 1024];			/* EBhEAeLXgobt@ */
	int win, timer, t = 120, l = 192 / 4, o = 4, q = 7;	/* nhƍĐp[h */
	int nold = 0, i, j;
	char s[32], *p, *r;

	/* t@C̎擾 */
	p = api_getcmd(s, 30, 0);

	/* t@C̓ǂݍ */
	i = api_fopen(p, 'r');
	if(i == 0) {
		end("̃t@C݂͑܂B");
	}
	j = api_fsize(i, 0);
	if(j > 256 * 1024 - 1) {
		j = 256 * 1024 - 1;
	}
	api_fread(i, tbuf, j);
	api_fclose(i);
	tbuf[j] = 0;
	r = tbuf;
	i = 0;	/* ʏ탂[h */

	/* EBhȄ */
	win = api_wopen(wbuf, 235, 37, -1, p);
	api_wbox(win, COLOR_000000, 1, 20, 233, 35);
	api_wrefresh(win, 1, 20, 234, 36);

	/* Rg󔒂̍폜 */
	for(p = tbuf; *p != 0; p++) {
		if(*p > ' ' && i == 0) {	/* Xy[XsR[hł͂Ȃ */
			if(*p == '#') {	/* sRg */
				i = 1;	/* sRg[h */
			} else {	/* ʂ̕ */
				*r = *p;
				if('a' <= *p && *p <= 'z') {	/* 啶ɕϊ */
					*r += 'A' - 'a';
				}
				r++;
			}
		} else if(i == 1 && *p == 0x0a) {	/* s */
			i = 0;	/* ʃ[h */
		}
	}
	*r = 0;

	/* ^C}̏ */
	timer = api_talloc();
	api_tinit(timer, 128);

	/* C */
	p = tbuf;
	for(;;){
		if(('A' <= *p && *p <= 'G') || *p == 'R') {	/* x */
			/* gvZ */
			if(*p == 'R') {
				i = 0;
			} else {
				i = o * 12 + ntable[*p - 'A'] + 12;
			}
			p++;
			if(*p == '+' || *p == '-') {
				if(*p == '-') {	/*  */
					i--;
				} else if(*p == '+') {	/* グ */
					i++;
				}
				p++;
			}
			if(i != nold) {
				if(28 <= nold && nold <= 107) {
					drawbar(win, nold, 0);
				}
				if(28 <= i && i <= 107) {
					drawbar(win, i, 1);
				}
				if(i != 0) {
					api_beep(ttable[i % 12] >> (17 - i / 12));
				} else {
					api_beep(0);
				}
				nold = i;
			}
			/* vZ */
			if('0' <= *p && *p <= '9') {	/*  */
				i = 192 / strtol(p, &p, 10);
			} else {
				i = l;
			}
			for(; *p == '.'; p++) {	/* t_1/2𑫂Ă */
				i += i / 2;
			}
			i *= (60 * 100 / 48);
			i /= t;
			if(q < 8 && *p != '&') {	/* ^CƃX[ */
				j = i * q / 8;
				wait(timer, j);
				if(28 <= nold && nold <= 107) {
					drawbar(win, nold, 0);
				}
				nold = 0;
				api_beep(0);
			} else {
				j = 0;
				if(*p == '&') {
					p++;
				}
			}
			wait(timer, i - j);
		} else if(*p == '<') {	/* IN^[u-- */
			p++;
			o--;
		} else if(*p == '>') {	/* IN^[u++ */
			p++;
			o++;
		} else if(*p == 'O') {	/* IN^[uw */
			o = strtol(p + 1, &p, 10);
		} else if(*p == 'Q') {	/* Qp[^w */
			q = strtol(p + 1, &p, 10);
		} else if(*p == 'L') {	/* ftHgw */
			l = strtol(p + 1, &p, 10);
			if(l == 0) {
				goto serror;
			}
			l = 192 / l;
			for(; *p == '.'; p++) {	/* t_1/2𑫂Ă */
				l += l / 2;
			}
		} else if(*p == 'T') {	/* e|w */
			t = strtol(p + 1, &p, 10);
		} else if(*p == 0) {
			p = tbuf;
		} else {
		serror:
			end("LqԈĂ܂B");
		}
	}
	api_exit();
}

void drawbar(int win, int l, char mode)
{
	if(mode == 0) {
		api_wbox(win, COLOR_000000, 1, 20, ((l - 28) + 1) * 3, 35);
		api_wrefresh(win, 1, 20, ((l - 28) + 2) * 3, 36);
		return;
	}
	if(l > 60) {
		api_wbox(win, COLOR_FF0000, 1, 20, ((l - 28) + 1) * 3, 35);
		api_wrefresh(win, 1, 21, ((l - 28) + 2) * 3, 36);
		l = 60;
	}
	api_wbox(win, COLOR_00FF00, 1, 20, ((l - 28) + 1) * 3, 35);
	api_wrefresh(win, 1, 21, ((l - 28) + 2) * 3, 36);
	return;
}

void wait(int timer, int time)
{
	int i;

	api_tset(timer, time);
	for(;;) {
		i = api_getd(1);
		if(i == 128) {
			break;
		}
	}
	return;
}

void end(char *s)
{
	if(s != 0) {
		api_puts(s);
	}
	api_beep(0);
	api_exit();
}
